# Making Custom Isolates

Need to do something more than what's supported by Direktiv? You can do just about anything by making your own custom functions to run as Isolates. To make things easier Direktiv makes its Isolates automatically from Docker images, but you can't just run any Docker image. In this article you'll learn how to make a Direktiv-compatible Docker image.

## Functions

Direktiv functions are only meant to be run for short lengths to time. They're meant to take some input, do something, optionally generate some output, and then return. To enforce this Direktiv will pull the plug on any instance that runs too long, and this timeout is separate from any timeouts defined in a workflow definition.

### Input Data

The data generated by Direktiv as action input will be saved to a file located at "`/direktiv-data/data.in`", usually as JSON. It is the function-author's responsibility to load this data and extract useful information from it. Input validation is optional, but encouraged.

### Output Data 

Data generated by the function should be saved in a file located at "`/direktiv-data/data.out`", also usually as JSON. Whatever is stored in this file will be returned to the calling workflow instance. 

### Reporting Errors

If something goes wrong a function can report an error to the calling workflow instance by saving some error information in as a small JSON object in "`/direktiv-data/error.json`". If this file is populated the execution of the function will be considered a failure regardless of what's stored in the output data file.

The JSON object can have two properties: `errorCode` and `errorMessage`. If an error message is defined without defining an error code the calling workflow instance will be marked as "crashed" without exposing any helpful information, so it's important to always define both. Errors raised by functions are always 'catchable' by their error codes.

Here's a sample error:

```json
{
  "errorCode": "myapp.input",
  "errorMessage": "Missing 'customerId' property in JSON input."
}
```

## Example

Have a look at the source code for one of the functions we've used a lot in these articles: https://github.com/vorteil/direktiv-apps/tree/master/requester.

## FAQs & Other Information 

### Function Logs 

The stdout & stderr from a function's main executable will be automatically logged to the calling instance's logs. Everything else is discarded. To force extra information into these logs write to "`/direktiv-data/log.log`" or "`/direktiv-data/error.log`".

Be aware that logs are saved to the disk, which could cause the virtual machine to run out of disk space if the function logs excessively.

### Disk Capacity

Direktiv automatically decides on an appropriate disk size when building the virtual machine. It should always be able to fit the files on the Docker image and it will add a generous amount extra to be safe, but it cannot know how much free space will be necessary for the function itself to run. If the disk fills up completely it could be difficult to debug because the error file and log files are stored on the same disk. 

### Networking

Direktiv configures the network so that isolates can reach out to the internet and receive responses. In general isolates have no externally routable IP address.
